@@ -1,4 +1,3 @@
-import os
 import sys
 import platform
 import multiprocessing
@@ -17,9 +16,14 @@ pytestmark = [
         platform.system() == 'Linux',
         reason="#410: keyring discovery fails intermittently",
     ),
+    pytest.mark.skipif(
+        # always skip as it crashes the interpreter
+        sys.version_info < (3, 8) and platform.system() == 'Darwin',
+        reason="#281, #494: Prior to 3.8, multiprocess invocation fails",
+    ),
     pytest.mark.xfail(
-        os.environ.get('AGENT_OS', '') == 'Windows_NT',
-        reason="#436: Multiprocessing fails on Azure Windows",
+        platform.system() == 'Windows' and sys.version_info > (3, 12),
+        reason="#634; apparent regression in CPython",
     ),
 ]
 
@@ -31,11 +35,6 @@ def test_multiprocess_get():
     assert proc1.exitcode == 0
 
 
-@pytest.mark.skipif(
-    # always skip as it crashes the interpreter
-    sys.version_info < (3, 8) and platform.system() == 'Darwin',
-    reason="#281: Prior to 3.8, multiprocess invocation fails",
-)
 def test_multiprocess_get_after_native_get():
     keyring.get_password('test_app', 'test_user')
     test_multiprocess_get()
